pub async fn mark_attempted(
conn: &mut PgConnection,
course_codes: &[String],
) -> ModelResult<()>Expand description
Stamps the codes a listing request is about to go out for.
pub async fn mark_attempted(
conn: &mut PgConnection,
course_codes: &[String],
) -> ModelResult<()>Stamps the codes a listing request is about to go out for.