pub fn roster_tier(
facts: &RosterTierFacts,
is_account_linking_enabled: bool,
now: DateTime<Utc>,
) -> RosterTierExpand description
How often a code’s roster is listed, from how recently it had a completion.
pub fn roster_tier(
facts: &RosterTierFacts,
is_account_linking_enabled: bool,
now: DateTime<Utc>,
) -> RosterTierHow often a code’s roster is listed, from how recently it had a completion.